# ___________________________________________________________________________________________
# 										|
# 	Automatic GunGame loader/unloader	|
# ______________________________________|
# This script automatically loads GunGame on "gg_" prefixed maps like gg_absinthe_shotty and,
# if enabled, it unloads GunGame on normal maps.
# It is also able to deactivate Mani Admin Plugins Rejoin Punishment on gg_* maps. This is
# helpfull if you want to run things like GG Deathmatch together with M.A.P.
# 
# Some note:	It won't load GunGame if you manually unloaded it during a GunGame map.
# 				This means if you typed "es_unload gungame" while the server was running
# 				a gg_* map, this script will stop auto-loading GunGame on mapchanges to the
# 				next gg_* maps. It will work again after a single mapchange to a normal map.
# 				
# 			Example:
# 				You unloaded GunGame on the map gg_absinthe_shotty. Then you did a mapchange
# 				to another gg_* map, but GunGame isn't loaded by this script.
# 				You have to do a mapchange to a map like de_dust. Now change back to a gg_*
# 				map, the script will now start loading GunGame automatically again.
# ===========================================================================================

# Map prefixes which trigger the script to load GunGame
# Set one or more prefixes (separated by commas)
# You can also set complete mapnames, to run GunGame on specific maps only
# Following would start GunGame on gg_* and aim_* maps plus the map cs_compound:
# ['gg_', 'aim_', 'cs_compound']
prefixes = ['gg_']

# GunGame Version to load
# Set this to what you want to load (the name of the folder located in .\eventscripts\)
# Common strings:
# 'gungame3'	for GunGame 3
# 'gungame4'	for GunGame 4
# 'gungame'		for GunGame 5
gungame_version = 'gungame'

# Auto unload GunGame on non gg_* maps (e.g. de_dust)?
# 0 = Don't unload GunGame on non gg_* maps
# 1 = Unload GunGame on non gg_* maps
auto_unload_gg = 1

# Auto disable the Anti-Rejoin module from Mani Admin Plugin on gg_* maps
# ==> Only enable this, if your server is running Mani Admin Plugin
# 0 = Don't disable Anti-Rejoin (People will get slayed when joining same round twice)
# 1 = Disable Anti-Rejoin (People will not get slayed)
auto_disable_ar = 0

# 
# DO NOT EDIT ANYTHING BELOW THIS LINE
# ___________________________________________________________________________________________

import es

gg_loaded = 0
firstround = 1

def es_map_start(event_var):
	global gungame_version, auto_unload_gg, gg_loaded, map, prefixes
	
	map = str(event_var['mapname']).lower()
	for mapprefix in prefixes:
		if mapprefix in map:
			isggmap = 1
			break
	else:
		isggmap = 0
	
	global isggmap
	
	if isggmap == 1 and gg_loaded == 0:
		es.server.queuecmd('es_load %s' % gungame_version)
		gg_loaded = 1
	else:
		if auto_disable_ar == 1 and gg_loaded == 1:
			firstround = 1
			global firstround
		if  isggmap == 0 and auto_unload_gg == 1 and gg_loaded == 1:
			es.server.queuecmd('es_unload %s' % gungame_version)
			gg_loaded = 0

def round_start(event_var):
	global auto_disable_ar, isggmap, firstround
	
	if auto_disable_ar == 1 and isggmap == 1 and firstround == 1:
		es.server.queuecmd('mani_anti_rejoin 0')
		firstround = 0